@@ -13,6 +13,21 @@
 #include <dcopref.h>
 
 
+extern "C"
+{
+    #include <stdio.h>
+    #include <fcntl.h>
+    #include <sys/ioctl.h>
+
+    #if defined(__linux__)
+    #undef __STRICT_ANSI__ // avoid error with /usr/include/linux/byteorder/little_endian.h
+    #include <linux/cdrom.h>
+    #elif defined(__FreeBSD_kernel__)
+    #include <sys/cdio.h>
+    #endif // if defined(__linux__)
+}
+
+
 // ### soundkonverter 0.4 implement reading of milliseconds/frames
 
 // TODO implement reading of cd data
@@ -61,7 +76,7 @@ CDDevice::CDDevice( const QString& _device )
         }
     }
 
-    para = new Paranoia();
+    Paranoia *para = new Paranoia();
     for( i = 0; i < (int)s.count(); i++ ) {
         if( init = para->init(s[i]) ) {
             device = s[i];
@@ -99,13 +114,14 @@ CDDevice::CDDevice( const QString& _device )
             }
         }
         delete cddb;
+        para->discClose();
     }
     else {
         KMessageBox::information( 0, i18n("No audio CD found."), i18n("Warning") );
         device = "";
-        delete para;
-        para = 0;
     }
+    delete para;
+    para = 0;
 }
 
 CDDevice::~CDDevice()
@@ -125,7 +141,7 @@ QString CDManager::newCDDevice( const QString& device )
     CDDevice* cdDevice = new CDDevice( device );
 
     for( QValueList<CDDevice*>::Iterator it = cdDevices.begin(); it != cdDevices.end(); ++it ) {
-        if( (*it)->device = cdDevice->device ) {
+        if( (*it)->device = cdDevice->device ) { // FIXME bug?
             cdDevices.remove( *it );
             delete (*it);
             break;
@@ -188,3 +204,40 @@ void CDManager::setDiscTags( const QString& device, TagData* tags )
     }
 }
 
+bool CDManager::ejectDevice()
+{
+    int status = -1;
+
+    for( QValueList<CDDevice*>::Iterator it = cdDevices.begin(); it != cdDevices.end(); ++it ) {
+        if((*it)->device.length() == 0) {
+            fprintf(stderr, "No device set...\n");
+            return false;
+        }
+
+        fprintf(stdout, "Trying to eject device `%s'\n", (*it)->device.ascii());
+
+        int fd;
+
+        fd = open((*it)->device.ascii(), O_RDWR|O_NONBLOCK);
+        if (fd == -1) {
+            fprintf(stderr, "unable to open `%s'\n", (*it)->device.ascii());
+            return false;
+        }
+
+        // Taken from the eject-tool, eject using CDROMEJECT ioctl. Return true if successful, false otherwise.
+        #if defined(CDROMEJECT)
+        status = ioctl(fd, CDROMEJECT);
+        #elif defined(CDIOCEJECT)
+        status = ioctl(fd, CDIOCEJECT);
+        #else
+        // Some kernels implement cdrom-eject only, but I don't think any kernel in the
+        // world would implement eject only for non-cdrom drives.  Let's die.
+        fprintf(stderr, "Cannot eject device, no supported interface found: `%s'\n", (*it)->device.ascii());
+        #endif
+
+        close(fd);
+    }
+
+    return (status == 0);
+}
+
