@@ -95,7 +95,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     albumBox->addWidget( iDisc );
     QLabel* lYearLabel = new QLabel( i18n("Year:"), this, "lYearLabel" );
     albumBox->addWidget( lYearLabel );
-    iYear = new KIntSpinBox( 0, 9999, 1, QDate::currentDate().year(), 10, this, "iYear" );
+    iYear = new KIntSpinBox( 0, 99999, 1, QDate::currentDate().year(), 10, this, "iYear" );
     albumBox->addWidget( iYear );
     QLabel* lGenreLabel = new QLabel( i18n("Genre:"), this, "lGenreLabel" );
     albumBox->addWidget( lGenreLabel );
@@ -275,11 +275,9 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     QString genre = "";
 
     device = cdManager->newCDDevice( _device );
-    // TODO abort, when no audio cd is found
-    /*if( device.isEmpty() ) {
-        emit reject();
-        return;
-    }*/
+    // don't execute the dialog, if no audio cd was found
+    noCD = device.isEmpty();
+
     QValueList<TagData*> tags = cdManager->getTrackList( device );
     for( QValueList<TagData*>::Iterator it = tags.begin(); it != tags.end(); ++it ) {
         if( artist == "" ) artist = (*it)->artist;
