@@ -114,6 +114,7 @@ void Config::read()
     data.general.askForNewOptions = conf->readBoolEntry( "askForNewOptions", true );
     data.general.executeUserScript = conf->readBoolEntry( "executeUserScript", false );
     data.general.showToolBar = conf->readBoolEntry( "showToolBar", false );
+    data.general.outputFilePermissions = conf->readNumEntry( "outputFilePermissions", 644 );
 
     conf->setGroup( "Plugins" );
     data.plugins.checkForUpdates = conf->readBoolEntry( "checkForUpdates", false );
@@ -299,6 +300,7 @@ void Config::write( bool sync )
     conf->writeEntry( "askForNewOptions", data.general.askForNewOptions );
     conf->writeEntry( "executeUserScript", data.general.executeUserScript );
     conf->writeEntry( "showToolBar", data.general.showToolBar );
+    conf->writeEntry( "outputFilePermissions", data.general.outputFilePermissions );
 
     conf->setGroup( "Plugins" );
     conf->writeEntry( "checkForUpdates", data.plugins.checkForUpdates );
@@ -478,6 +480,7 @@ void Config::writeServiceMenu()
     num = 0;
     content = "";
     content += "[Desktop Entry]\n";
+    content += "Encoding=UTF-8\n";
     content += "ServiceTypes=";
 
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
@@ -520,6 +523,7 @@ void Config::writeServiceMenu()
     num = 0;
     content = "";
     content += "[Desktop Entry]\n";
+    content += "Encoding=UTF-8\n";
     content += "ServiceTypes=";
 
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
@@ -551,6 +555,89 @@ void Config::writeServiceMenu()
             file.close();
         }
     }
+
+    writeServiceMenuKDE4();
+}
+
+void Config::writeServiceMenuKDE4()
+{
+    int num;
+    QString content;
+    QFile file;
+
+    num = 0;
+    content = "";
+    content += "[Desktop Entry]\n";
+    content += "Type=Service\n";
+    content += "Encoding=UTF-8\n";
+    content += "ServiceTypes=KonqPopupMenu/Plugin,";
+
+    for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
+        if( (*it).decoder != 0 && binaries[(*it).decoder->dec.bin] != "" && (*it).mime_types.first() != "application/octet-stream" ) {
+            for( QStringList::Iterator b = (*it).mime_types.begin(); b != (*it).mime_types.end(); ++b ) {
+                content += (*b) + ",";
+                num++;
+            }
+        }
+    }
+
+    if( num != 0 )
+    {
+        content += "audio/x-wav";
+
+        content += "\n";
+        content += "Icon=soundkonverter\n";
+        content += "Actions=ConvertWithSoundkonverter;\n\n";
+
+        content += "[Desktop Action ConvertWithSoundkonverter]\n";
+        content += "Name="+i18n("Convert with soundKonverter ...")+"\n";
+        content += "Icon=soundkonverter\n";
+        content += "Exec=soundkonverter %F\n";
+
+        file.setName( QDir::homeDirPath()+"/.kde4/share/kde4/services/ServiceMenus/convert_with_soundkonverter.desktop" );
+        if ( file.open( IO_WriteOnly ) ) {
+            QTextStream stream( &file );
+            stream << content;
+            file.close();
+        }
+    }
+
+    num = 0;
+    content = "";
+    content += "[Desktop Entry]\n";
+    content += "Type=Service\n";
+    content += "Encoding=UTF-8\n";
+    content += "ServiceTypes=KonqPopupMenu/Plugin,";
+
+    for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
+        if( (*it).replaygain != 0 && binaries[(*it).replaygain->replaygain.bin] != "" && (*it).mime_types.first() != "application/octet-stream" ) {
+            for( QStringList::Iterator b = (*it).mime_types.begin(); b != (*it).mime_types.end(); ++b ) {
+                content += (*b) + ",";
+                num++;
+            }
+        }
+    }
+
+    if( num != 0 )
+    {
+        content = content.left(content.length()-1);
+
+        content += "\n";
+        content += "Icon=soundkonverter_replaygain\n";
+        content += "Actions=AddReplayGainWithSoundkonverter;\n\n";
+
+        content += "[Desktop Action AddReplayGainWithSoundkonverter]\n";
+        content += "Name="+i18n("Add Replay Gain with soundKonverter ...")+"\n";
+        content += "Icon=soundkonverter_replaygain\n";
+        content += "Exec=soundkonverter --replaygain %F\n";
+
+        file.setName( QDir::homeDirPath()+"/.kde4/share/kde4/services/ServiceMenus/add_replaygain_with_soundkonverter.desktop" );
+        if( file.open(IO_WriteOnly) ) {
+            QTextStream st( &file );
+            st << content;
+            file.close();
+        }
+    }
 }
 
 void Config::writeAmarokScript()
