@@ -251,6 +251,7 @@ public:
             bool askForNewOptions;
             bool executeUserScript;
             bool showToolBar;
+            int outputFilePermissions;
         } general;
         struct Plugins {
             bool checkForUpdates;
@@ -323,6 +324,7 @@ private:
      * Generate the service menu
      */
     void writeServiceMenu();
+    void writeServiceMenuKDE4();
 
     /**
      * Copy the amarok script
