@@ -24,6 +24,7 @@
 
 #include <qfile.h>
 #include <qtimer.h>
+#include <qfileinfo.h>
 
 ConvertItem::ConvertItem()
 {
@@ -651,12 +652,10 @@ void Convert::putCorrection( ConvertItem* item )
 
     QString src = item->correctionOutFile;
 
-    QString dest = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config,item->correctionOutputExtension) ).replace("%2f","%252f");
+    item->outputFilePathNameCorrection = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config,item->correctionOutputExtension) ).replace("%2f","%252f");
 
     KURL source( src );
-//     KURL destination( dest );
-    KURL destination;
-    destination.setPath( dest );
+    KURL destination( item->outputFilePathNameCorrection );
 
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Moving correction file")+"... 00 %" );
 
@@ -683,6 +682,33 @@ void Convert::putCorrection( ConvertItem* item )
     }
 }
 
+void Convert::changePermissions( ConvertItem* item )
+{
+    logger->log( item->logID, i18n("Changing permissions") );
+    item->state = ConvertItem::permissions;
+
+//     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Changing permissions")+"... 00 %" );
+
+    KURL file( item->outputFilePathName );
+    KURL fileCorrection( item->outputFilePathNameCorrection );
+
+    item->convertProcess->clearArguments();
+
+    *(item->convertProcess) << "chmod";
+    *(item->convertProcess) << QString::number(config->data.general.outputFilePermissions);
+    *(item->convertProcess) << file.path();
+    if( item->mode & ConvertItem::put_correction ) {
+        *(item->convertProcess) << fileCorrection.path();
+        logger->log( item->logID, "chmod " + QString::number(config->data.general.outputFilePermissions) + " \"" + file.path() + "\" \"" + fileCorrection.path() + "\"" );
+    }
+    else {
+        logger->log( item->logID, "chmod " + QString::number(config->data.general.outputFilePermissions) + " \"" + file.path() + "\"" );
+    }
+
+    item->convertProcess->setPriority( config->data.general.priority );
+    item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+}
+
 void Convert::executeUserScript( ConvertItem* item )
 {
     logger->log( item->logID, i18n("Running user script") );
@@ -727,6 +753,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -740,6 +767,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -752,6 +780,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -763,6 +792,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -773,6 +803,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -782,6 +813,7 @@ void Convert::executeNextStep( ConvertItem* item )
             if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -790,6 +822,7 @@ void Convert::executeNextStep( ConvertItem* item )
         {
             if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -797,11 +830,19 @@ void Convert::executeNextStep( ConvertItem* item )
         case ConvertItem::put:
         {
             if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
         case ConvertItem::put_correction:
+        {
+            if( item->mode & ConvertItem::permissions ) changePermissions( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
+            else remove( item );
+            break;
+        }
+        case ConvertItem::permissions:
         {
             if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
@@ -823,6 +864,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( item->mode & ConvertItem::permissions ) changePermissions( item );
             else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
@@ -1256,7 +1298,7 @@ void Convert::processExit( KProcess* proc )
                 }
             }
             if( (*item)->state == ConvertItem::replaygain ) {
-                if( proc->signalled() ) {
+                /*if( proc->signalled() ) {
                     emit uncountTime( (*item)->getTime );
                     emit uncountTime( (*item)->getCorrectionTime );
                     emit uncountTime( (*item)->ripTime );
@@ -1276,9 +1318,9 @@ void Convert::processExit( KProcess* proc )
                     updateProgressIndicator();
                     return;
                 }
-                else {
+                else {*/
                     emit countTime( (*item)->replaygainTime );
-                }
+                //}
             }
             // TODO did we get errors? (complete)
             executeNextStep( *item );
@@ -1384,6 +1426,8 @@ void Convert::add( FileListItem* item )
 
     (*newItem)->mode = ConvertItem::Mode( (*newItem)->mode | ConvertItem::write_tags | ConvertItem::put );
 
+    if( config->data.general.outputFilePermissions != 0 ) (*newItem)->mode = ConvertItem::Mode( (*newItem)->mode | ConvertItem::permissions );
+
     // TODO use the values from the format info files !!!
 
     if( (*newItem)->mode & ConvertItem::get ) {
@@ -1465,9 +1509,20 @@ void Convert::remove( ConvertItem* item, int state )
     //emit uncountTime( item->getTime + item->getCorrectionTime + item->ripTime +
     //                  item->decodeTime + item->encodeTime + item->replaygainTime );
 
+    // check file sizes to detect a conversion error
+    QString inputFile = ( item->mode & ConvertItem::rip ) ? item->tempWavFile->name() : item->tempInFile->name();
+    QFileInfo inputFileInfo( inputFile );
+    QString outputFile = ( item->mode & ConvertItem::encode ) ? item->tempOutFile->name() : item->tempWavFile->name();
+    QFileInfo outputFileInfo( outputFile );
+    if( outputFileInfo.size()*100 < inputFileInfo.size() ) {
+        state = -1;
+        logger->log( item->logID, i18n("Output file too small (%1 bytes)").arg(outputFileInfo.size()) );
+    }
+    logger->log( item->logID, i18n("verhältnis: %1").arg((float)inputFileInfo.size()/(outputFileInfo.size()*100)) );
+
     logger->log( item->logID, i18n("Removing file from conversion list. Exit code %1").arg(state) );
 
-    if( item->fileListItem->notify != "" ) {
+    if( item->fileListItem->notify != "" && state == 0 ) {
         QString command = item->fileListItem->notify;
         command.replace( "%u", item->fileListItem->url );
         command.replace( "%i", item->fileListItem->options.filePathName.replace(" ","%20") );
