@@ -345,7 +345,7 @@ void OptionsEditor::itemsSelected( QValueList<FileListItem*> items )
     pEditTags->hide();
 
     if( items.count() == 1 ) {
-        setCaption( items.first()->fileName );
+        setCaption( KURL::decode_string(items.first()->fileName).replace("%2f","/").replace("%%","%") );
         // HACK ...but seems to work...
         // FIXME directory does get set properly
         disconnect( options, SIGNAL(optionsChanged()), 0, 0 );
