@@ -103,8 +103,11 @@ bool Paranoia::findCdrom()
 	char dev[4][4]={"","","",""};
 
 	f = new QFile( "/proc/sys/dev/cdrom/info" );
-	if ( !f->open(IO_ReadOnly) )
-		return false;
+        if ( !f->open(IO_ReadOnly) ) {
+            f->close();
+            delete f;
+            return false;
+        }
 
 	QTextStream t( f );
 	while ( !t.eof() && !stop ) {
@@ -112,16 +115,22 @@ bool Paranoia::findCdrom()
 		if ( s.contains("drive name:") )
 			stop = true;
 	}
-	if ( !stop )
-		return false;
+	if ( !stop ) {
+            f->close();
+            delete f;
+            return false;
+        }
 
 	pos = s.find(":");
 	c = s.right( s.length()-pos-1 );
 	sscanf( c.latin1(), "%s %s %s %s", dev[0], dev[1], dev[2], dev[3] );
 
 	for ( i=0; i<4; i++ )
-		if ( procCdrom( dev[i] ) )
-			return true;
+		if ( procCdrom( dev[i] ) ) {
+                    f->close();
+                    delete f;
+                    return true;
+                }
 
 	f->close();
 	return false;
@@ -196,6 +205,13 @@ int Paranoia::discLastSector()
 }
 
 
+int Paranoia::discClose()
+{
+        int ret = cdda_close( d );
+        d = 0;
+        return ret;
+}
+
 
 bool Paranoia::isAudio( int t )
 {
@@ -246,7 +262,7 @@ long Paranoia::trackTime( int t )
 Paranoia::~Paranoia()
 {
 	if ( p!=0 ) paranoia_free( p );
-	if (d!=0 ) cdda_close( d );
+	if ( d!=0 ) cdda_close( d );
 }
 
 
