@@ -305,22 +305,22 @@ bool ReplayGainFileList::acceptDrag( QDropEvent* e ) const
 void ReplayGainFileList::slotDropped( QDropEvent* e, QListViewItem*, QListViewItem* )
 {
     QString file;
-    QStringList list;
-    if( KURLDrag::decodeLocalFiles( e, list ) )
+    KURL::List list;
+    if( KURLDrag::decode( e, list ) )
     {
-        for( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
+        for( KURL::List::Iterator it = list.begin(); it != list.end(); ++it )
         {
             // TODO verify the files (necessary when multiple files are being dropped)
-            file = QDir::convertSeparators( *it );
+            file = QDir::convertSeparators( (*it).pathOrURL() );
             QFileInfo fileInfo( file );
-            if( fileInfo.isFile() )
-            {
-                addFile( file );
-            }
-            else if( fileInfo.isDir() )
+            if( fileInfo.isDir() )
             {
                 addDir( file );
             }
+            else
+            {
+                addFile( (*it).url() );
+            }
         }
     }
 }
@@ -495,7 +495,7 @@ void ReplayGainFileList::contentsDropEvent( QDropEvent *e )
     }
 }
 
-int ReplayGainFileList::listDir( const QString& directory, QStringList filter, bool fast, int count )
+int ReplayGainFileList::listDir( const QString& directory, QStringList filter, bool recursive, bool fast, int count )
 { // NOTE speed up?
     QDir dir( directory );
     dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoSymLinks | QDir::Readable );
@@ -506,12 +506,13 @@ int ReplayGainFileList::listDir( const QString& directory, QStringList filter, b
         if( *it == "." || *it == ".." ) continue;
         QFileInfo fileInfo( directory + "/" + *it );
         if( fast ) {
-            if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, filter, fast, count );
+            if( fileInfo.isDir() && recursive ) {
+                count = listDir( directory + "/" + *it, filter, recursive, fast, count );
             }
-            else {
+            else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
+                // NOTE filter feature
                 for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
-                    if( (*it).endsWith("."+(*jt)) ) {
+                    if( (*it).endsWith("."+(*jt),false) ) {
                         count++;
                         pScanStatus->setTotalSteps( count );
                         break;
@@ -524,20 +525,21 @@ int ReplayGainFileList::listDir( const QString& directory, QStringList filter, b
             }
         }
         else {
-            if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, filter, fast, count );
+            if( fileInfo.isDir() && recursive ) {
+                count = listDir( directory + "/" + *it, filter, recursive, fast, count );
             }
-            else {
+            else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
+                // NOTE filter feature
                 for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
-                    if( (*it).endsWith("."+(*jt)) ) {
-                        addFile( directory + "/" + *it );
+                    if( (*it).endsWith("."+(*jt),false) ) {
+                        addFile( KURL::encode_string(directory + "/" + *it) );
                         count++;
                         pScanStatus->setProgress( count );
                         break;
                     }
                 }
                 if( filter.first() == "" ) {
-                    addFile( directory + "/" + *it );
+                    addFile( KURL::encode_string(directory + "/" + *it) );
                     count++;
                     pScanStatus->setProgress( count );
                 }
@@ -585,29 +587,6 @@ void ReplayGainFileList::addFile( const QString& file )
     QString filePathName;
     QString device;
 
-//         filename.replace( " ", "%20" );
-//         filename.replace( "<", "%3c" );
-//         filename.replace( ">", "%3e" );
-        filename.replace( "#", "%23" );
-//         filename.replace( "%", "%25" );
-//         filename.replace( "{", "%7b" );
-//         filename.replace( "}", "%7d" );
-//         filename.replace( "|", "%7c" );
-//         filename.replace( "\\","%5c" );
-//         filename.replace( "^", "%5e" );
-//         filename.replace( "~", "%7e" );
-//         filename.replace( "[", "%5b" );
-//         filename.replace( "]", "%5d" );
-//         filename.replace( "`", "%60" );
-//         filename.replace( ";", "%3b" );
-//         filename.replace( "/", "%2f" );
-        filename.replace( "?", "%3f" );
-//         filename.replace( ":", "%3a" );
-//         filename.replace( "@", "%40" );
-//         filename.replace( "=", "%3d" );
-//         filename.replace( "&", "%26" );
-//         filename.replace( "$", "%24" );
-
     if( filename.left( 1 ) == "/" ) {
         filePathName = filename;
     }
@@ -652,23 +631,21 @@ void ReplayGainFileList::addFile( const QString& file )
         return;
     }
 
-    TagData* tags = tagEngine->readTags( filePathName );
+    TagData* tags = tagEngine->readTags( KURL::decode_string(filePathName) );
     if( !tags || tags->album.isEmpty() ) {
         ReplayGainFileListItem* item = new ReplayGainFileListItem( this );
         item->originalFileFormat = filePathName.right( filePathName.length() - filePathName.findRev(".") - 1 );
         item->mimeType = KMimeType::findByFileContent( filePathName )->name();
         item->fileFormat = KMimeType::findByFileContent( filePathName )->patterns().first();
         if( item->mimeType.isEmpty() || item->mimeType == "application/octet-stream" || item->mimeType == "text/plain" ) {
-            item->mimeType = KMimeType::findByURL( filePathName )->name();
-            item->fileFormat = KMimeType::findByURL( filePathName )->patterns().first();
+            item->mimeType = KMimeType::findByURL( filePathName.lower() )->name();
+            item->fileFormat = KMimeType::findByURL( filePathName.lower() )->patterns().first();
         }
         // check whether the mime type has a decoder registered
         if( !config->acceptReplayGainFile( item->mimeType ) ) {
             delete item;
             return;
         }
-        filePathName.replace( "%3f", "?" );
-        filePathName.replace( "%23", "#" );
         item->filePathName = filePathName;
         if( tags ) item->time = tags->length;
         else {
@@ -681,7 +658,7 @@ void ReplayGainFileList::addFile( const QString& file )
                 item->time = 210;
             }
         }
-        item->setText( columnByName(i18n("File")), filePathName );
+        item->setText( columnByName(i18n("File")), KURL::decode_string(filePathName).replace("%2f","/").replace("%%","%") );
         if( tags && tags->track_gain != 210588 ) {
             item->setText( columnByName(i18n("Track")), QString().sprintf("%+.2f dB",tags->track_gain) );
         }
@@ -699,8 +676,8 @@ void ReplayGainFileList::addFile( const QString& file )
         QString mimeType = KMimeType::findByFileContent( filePathName )->name();
         QString fileFormat = KMimeType::findByFileContent( filePathName )->patterns().first();
         if( mimeType.isEmpty() || mimeType == "application/octet-stream" || mimeType == "text/plain" ) {
-            mimeType = KMimeType::findByURL( filePathName )->name();
-            fileFormat = KMimeType::findByURL( filePathName )->patterns().first();
+            mimeType = KMimeType::findByURL( filePathName.lower() )->name();
+            fileFormat = KMimeType::findByURL( filePathName.lower() )->patterns().first();
         }
         // check whether the mime type has a decoder registered
         if( !config->acceptReplayGainFile( mimeType ) ) {
@@ -712,13 +689,11 @@ void ReplayGainFileList::addFile( const QString& file )
             if( it->text(columnByName(i18n("File"))) == tags->album && it->type() == ReplayGainFileListItem::Album && it->mimeType == mimeType ) {
                 ReplayGainFileListItem* item = new ReplayGainFileListItem( it );
                 item->originalFileFormat = filePathName.right( filePathName.length() - filePathName.findRev(".") - 1 );
-                filePathName.replace( "%3f", "?" );
-                filePathName.replace( "%23", "#" );
                 item->filePathName = filePathName;
                 item->mimeType = mimeType;
                 item->fileFormat = fileFormat;
                 item->time = tags->length;
-                item->setText( columnByName(i18n("File")), filePathName );
+                item->setText( columnByName(i18n("File")), KURL::decode_string(filePathName).replace("%2f","/").replace("%%","%") );
                 if( tags->track_gain != 210588 ) {
                     item->setText( columnByName(i18n("Track")), QString().sprintf("%+.2f dB",tags->track_gain) );
                 }
@@ -731,11 +706,11 @@ void ReplayGainFileList::addFile( const QString& file )
                 else {
                     item->setText( columnByName(i18n("Album")), i18n("Unknown") );
                 }
-                tags = 0;   // <--,
-                break;    //    |
+                tags = 0;  // <--,
+                break;     //    |
             }              //    |
-        }                 //    |
-        if( tags ) {     // <--'
+        }                  //    |
+        if( tags ) {       // <--'
             ReplayGainFileListItem* parent = new ReplayGainFileListItem( this );
             //parent->setText( 0, tags->artist+" - "+tags->album );
             parent->setText( columnByName(i18n("File")), tags->album );
@@ -744,13 +719,11 @@ void ReplayGainFileList::addFile( const QString& file )
             parent->fileFormat = fileFormat;
             ReplayGainFileListItem* item = new ReplayGainFileListItem( parent );
             item->originalFileFormat = filePathName.right( filePathName.length() - filePathName.findRev(".") - 1 );
-            filePathName.replace( "%3f", "?" );
-            filePathName.replace( "%23", "#" );
             item->filePathName = filePathName;
             item->mimeType = mimeType;
             item->fileFormat = fileFormat;
             item->time = tags->length;
-            item->setText( columnByName(i18n("File")), filePathName );
+            item->setText( columnByName(i18n("File")), KURL::decode_string(filePathName).replace("%2f","/").replace("%%","%") );
             if( tags->track_gain != 210588 ) {
                 item->setText( columnByName(i18n("Track")), QString().sprintf("%+.2f dB",tags->track_gain) );
             }
@@ -767,15 +740,15 @@ void ReplayGainFileList::addFile( const QString& file )
     }
 }
 
-void ReplayGainFileList::addDir( const QString& directory, const QStringList& filter )
+void ReplayGainFileList::addDir( const QString& directory, const QStringList& filter, bool recursive )
 {
     pScanStatus->setProgress( 0 );
     pScanStatus->setTotalSteps( 0 );
     pScanStatus->show(); // show the status while scanning the directories
     kapp->processEvents();
 
-    int count = listDir( directory, filter, true );
-    listDir( directory, filter );
+    int count = listDir( directory, filter, recursive, true );
+    listDir( directory, filter, recursive );
 
     pScanStatus->hide(); // hide the status bar, when the scan is done
 }
@@ -936,7 +909,7 @@ void ReplayGainFileList::removeSelectedItemsGain()
 
 void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
 {
-    logID = logger->registerProcess( item->text(columnByName(i18n("File"))) );
+    logID = logger->registerProcess( KURL::encode_string(item->text(columnByName(i18n("File")))) );
     logger->log( logID, "Mime Type: " + item->mimeType );
     logger->log( logID, i18n("Applying Replay Gain") );
 
@@ -969,7 +942,7 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
             else if( album_gain != current_gain ) skip = false;
         }
 
-        if( !skip || album_gain == i18n("Unknown") ) {
+        if( !skip || album_gain == i18n("Unknown") || force ) {
             if( force ) {
                 replayGain->apply( fileList, item->mimeType, process, logID, ReplayGain::Mode(ReplayGain::calc_album|ReplayGain::force) );
             }
@@ -978,6 +951,7 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
             }
         }
         else {
+            logger->processCompleted( logID, 0 );
             item->addingReplayGain = false;
             item->repaint();
             for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
@@ -1008,7 +982,7 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
 
 void ReplayGainFileList::removeReplayGain( ReplayGainFileListItem* item )
 {
-    int logID = logger->registerProcess( item->filePathName );
+    logID = logger->registerProcess( KURL::encode_string(item->text(columnByName(i18n("File")))) );
     logger->log( logID, "Mime Type: " + item->mimeType );
     logger->log( logID, i18n("Removing Replay Gain") );
 
@@ -1228,7 +1202,7 @@ void ReplayGainFileList::processExit( KProcess* proc )
                 processedTime += item->time;
                 item->addingReplayGain = false;
                 item->repaint();
-                item->updateReplayGainCells( tagEngine->readTags(item->filePathName) );
+                item->updateReplayGainCells( tagEngine->readTags(KURL::decode_string(item->filePathName)) );
             }
             if( item->queued && proc->signalled() ) {
                 item->queued = false;
@@ -1243,7 +1217,7 @@ void ReplayGainFileList::processExit( KProcess* proc )
                     processedTime += sub_item->time;
                     sub_item->addingReplayGain = false;
                     sub_item->repaint();
-                    sub_item->updateReplayGainCells( tagEngine->readTags(sub_item->filePathName) );
+                    sub_item->updateReplayGainCells( tagEngine->readTags(KURL::decode_string(sub_item->filePathName)) );
                 }
             }
             if( item->queued && proc->signalled() ) {
@@ -1259,7 +1233,7 @@ void ReplayGainFileList::processExit( KProcess* proc )
                     processedTime += sub_item->time;
                     sub_item->addingReplayGain = false;
                     sub_item->repaint();
-                    sub_item->updateReplayGainCells( tagEngine->readTags(sub_item->filePathName) );
+                    sub_item->updateReplayGainCells( tagEngine->readTags(KURL::decode_string(sub_item->filePathName)) );
                 }
                 if( sub_item->queued && proc->signalled() ) {
                     sub_item->queued = false;
