@@ -63,7 +63,7 @@ soundKonverter::soundKonverter()
     configStartPage = ConfigDialog::GeneralPage;
 
     logger = new Logger();
-    logger->log( 1000, "This is soundKonverter 0.3.7" );
+    logger->log( 1000, "This is soundKonverter 0.3.10" );
     #ifdef HAVE_MP4V2
         logger->log( 1000, "MP4v2 is enabled" );
     #else
@@ -160,6 +160,8 @@ soundKonverter::soundKonverter()
     new KAction( i18n("L&oad file list"), "fileopen", 0, fileList, SLOT(load()), actionCollection(), "load" );
     new KAction( i18n("Sa&ve file list"), "filesave", 0, fileList, SLOT(save()), actionCollection(), "save" );
 
+    new KAction( i18n("&Eject CD"), "run", 0, this, SLOT(ejectCdrom()), actionCollection(), "eject" );
+
     // TODO //KStdAction::paste( this, SLOT(pasteFiles()), actionCollection() );
 
     KStdAction::preferences( this, SLOT(showConfigDialog()), actionCollection() );
@@ -776,5 +778,10 @@ void soundKonverter::setTitle( const QString& title )
     setCaption( title );
 }
 
+void soundKonverter::ejectCdrom()
+{
+    cdManager->ejectDevice();
+}
+
 
 #include "soundkonverter.moc"
